/******************************************************************************
 * About_Command.java - Tell the client about jIBS.
 * $Id: About_Command.java,v 1.3 2011/06/09 18:06:46 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: About_Command.java,v $
 * Revision 1.3  2011/06/09 18:06:46  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;

/** Tell the client about jIBS.
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.3 $ <br> $Date: 2011/06/09 18:06:46 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/About_Command.java">cvs About_Command.java</a>
 */
public class About_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		output_about(jibsServer, player);

		return true;
	}

	private void output_about(JibsServer jibsServer, Player player) {
		BufferedReader reader = null;

		try {
			File abaoutFile = new File(jibsServer.getResource("about"));
			reader = new BufferedReader(new FileReader(abaoutFile));

			String line = "";

			do {
				line = reader.readLine();

				if (line != null) {
					if (line.equals("")) {
						line = " ";
					}

					player.println(line);
				}
			} while (line != null);

			reader.close();
		} catch (FileNotFoundException e) {
			jibsServer.logException(e);
		} catch (IOException e) {
			jibsServer.logException(e);
		} finally {
			try {
				if (reader != null) {
					reader.close();
				}
			} catch (IOException e) {
				jibsServer.logException(e);
			}
		}
	}

}
