/******************************************************************************
 * Kibitz_Command - Handle kibitzing.
 * $Id: Kibitz_Command.java,v 1.6 2011/06/24 01:42:04 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Kibitz_Command.java,v $
 * Revision 1.6  2011/06/24 01:42:04  dick
 * Finish kibitz handling.
 *
 * Revision 1.5  2011/06/09 18:19:18  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.4  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.3  2011/06/02 19:28:42  dick
 * informWatcher() becomes informWatchers().
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 * Revision 1.2  2011/05/28 00:49:03  dick
 * Warnings removal.
 *
 * Revision 1.1  2011/05/26 23:25:27  dick
 * Import jIBS 0.4.2 from sf.net.  Convert to Maven project.  Add BuckoSoft/gnu headers to all files.
 * This is a baseline for the import.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.backgammon.BackgammonBoard;
import net.sourceforge.jibs.backgammon.JibsGame;
import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;
import net.sourceforge.jibs.util.ClipConstants;

/** Handle kibitzing. <br>
 * Note: Doesn't handle telnet sessions correctly.
 * @author Axel Leucht
 * @author Dick Balaska
 * @since 2005/04/18
 * @version $Revision: 1.6 $ <br> $Date: 2011/06/24 01:42:04 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Kibitz_Command.java">cvs Kibitz_Command.java</a>
 */
public class Kibitz_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		JibsMessages jibsMessages = jibsServer.getJibsMessages();
		String msg = null;
		JibsGame game = player.getGame();

		if (game == null && player.getWatchingPlayer() != null) 
			game = player.getWatchingPlayer().getGame();
		if (game != null) {
			BackgammonBoard board = game.getBackgammonBoard();
			Player player1 = board.getPlayerX();
			Player player2 = board.getPlayerO();

			player.println(ClipConstants.CLIP_YOU_KIBITZ + " " + strArgs);
			int heard = 0;
			msg = ClipConstants.CLIP_KIBITZES + " " + player.getName() +
					" " + strArgs;
			if (player1 != player) {
				player1.println(msg);
				heard++;
			}
			if (player2 != player) {
				player2.println(msg);
				heard++;
			}
			heard += player1.show2Watchers(msg, player);
			heard += player2.show2Watchers(msg, player);
			player.println("** " + heard + " user" + (heard != 1 ? "s" : "") +  " heard you.");				

		} else {
			// m_kibitz_no_play=** You're not watching or playing.
			msg = jibsMessages.convert("m_kibitz_no_play");
			player.println(msg);
		}

		return true;
	}
}
