/******************************************************************************
 * JibsTimer - Timer looking for idle threads.
 * $Id: JibsTimer.java,v 1.5 2011/06/11 19:18:35 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: JibsTimer.java,v $
 * Revision 1.5  2011/06/11 19:18:35  dick
 * Stop passing jibsServer all around.  If anybody wants it, they can do JibsServer.getInstance().
 *
 * Revision 1.4  2011/06/06 03:18:27  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.3  2011/06/05 18:26:34  dick
 * log is a method of JibsServer.  Always write screen logs to the log file.
 * So, no need to pass write-to-logs=true from everywhere.
 *
 * Revision 1.2  2011/05/31 15:25:49  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.util;

import net.sourceforge.jibs.server.ClientWorker;
import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;

/** Timer looking for idle threads.
 * 
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.5 $ <br> $Date: 2011/06/11 19:18:35 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/util/JibsTimer.java">cvs JibsTimer.java</a>
 */
public class JibsTimer implements Runnable {
	private JibsServer jibsServer;
	private ClientWorker cw;
	private Player player;
	private long millis;

	public JibsTimer(ClientWorker cw, Player player,
			long millis) {
		this.jibsServer = JibsServer.getInstance();
		this.cw = cw;
		this.player = player;
		this.millis = millis;
	}

	public void run() {
		try {
			Thread.sleep(millis);

			JibsMessages jm = jibsServer.getJibsMessages();
			Object[] obj = null;
			String msg = null;

			if (player != null) {
				obj = new Object[] { player.getName() };
			} else {
				obj = new Object[] { "\"<Unknown>\"" };
			}

			// m_client_inactive="** Client '%0' was inactive too long.
			msg = jm.convert("m_client_inactive", obj);
			jibsServer.log(msg);
			cw.executeCmd("bye");
		} catch (InterruptedException e) {
			// jibsServer.logException(e);
		}
	}
}
